#include <iostream>
#include <map>
#include <vector>
#include <cmath>
#include <algorithm>
#include <set>

using namespace std;

int k, n;

map<int, int> coords;
map<int, int> rcoords;

struct Event {
    int x, y, i, op, h;
    Event(int x, int i, int op, int h, int y): x(x), i(i), op(op), h(h), y(y) {}
    bool operator<(const Event& b) const {
        if (x ^ b.x) return x < b.x;
        if (x ^ b.op) return op < b.op;
        return i < b.i;
    }
};
vector<Event> evs;

struct SegmentTree {
    vector<int> tree;
    vector<int> color;
    int len;
    SegmentTree(int size) {
        len = (1 << (int)ceil(log2(size) + 1)) - 1;
        tree.resize(len, 0);
        color.resize(len, 0);
    }
    void push(int v, int l, int m, int r) {
        if (color[v]) {
            color[2 * v + 1] += color[v];
            color[2 * v + 2] += color[v];

            tree[2 * v + 1] += color[v] * (rcoords[m] - rcoords[l]);
            tree[2 * v + 2] += color[v] * (rcoords[r] - rcoords[m]);

            color[v] = 0;
        }
    }
    void update(int v, int l, int r, int ql, int qr, int x) {
        if (r <= ql || qr <= l) {
            return;
        }
        if (ql <= l && r <= qr) {
            color[v] += x;
            tree[v] += (rcoords[r] - rcoords[l]) * x;
            return;
        }
        int m = (l + r) / 2;
        push(v, l, m, r);
        update(2 * v + 1, l, m, ql, qr, x);
        update(2 * v + 2, m, r, ql, qr, x);
        tree[v] = tree[2 * v + 1] + tree[2 * v + 2];
    }
    void update(int l, int r, int x) {
        update(0, 0, len / 2 + 1, l, r, x);
    }
    int sum(int v, int l, int r, int ql, int qr) {
        if (r <= ql || qr <= l) {
            return 0;
        }
        if (ql <= l && r <= qr) {
            return tree[v];
        }
        int m = (l + r) / 2;
        push(v, l, m, r);
        return sum(2 * v + 1, l, m, ql, qr) +
        sum(2 * v + 2, m, r, ql, qr);
    }
    int sum(int l, int r) {
        return sum(0, 0, len / 2 + 1, l, r);
    }
};

signed main() {
    cin >> k >> n;
    int currx = 0, curry = 0;
    for (int i = 0; i < n; i++) {
        char v;
        int ai;
        cin >> v >> ai;
        if (v == 'E') {
            evs.emplace_back(currx, i, 1, k, curry);
            evs.emplace_back(currx + ai + k, i, 0, k, curry);
            currx += ai;
        } else if (v == 'N') {
            evs.emplace_back(currx, i, 1, k + ai, curry);
            evs.emplace_back(currx + k, i, 0, k + ai, curry);
            curry += ai;
        } else if (v == 'W') {
            evs.emplace_back(currx - ai, i, 1, k, curry);
            evs.emplace_back(currx + k, i, 0, k, curry);
            currx -= ai;
        } else {
            evs.emplace_back(currx, i, 1, k + ai, curry - ai);
            evs.emplace_back(currx + k, i, 0, k + ai, curry - ai);
            curry -= ai;
        }
    }
    set<int> hs;
    for (int i = 0; i < evs.size(); i++) {
        hs.insert(evs[i].y);
        hs.insert(evs[i].y + evs[i].h);
    }
    int cnt = 0;
    for (auto i : hs) {
        rcoords[cnt] = i;
        coords[i] = cnt++;
    }
    sort(evs.begin(), evs.end());
    int prev = evs[0].x;
    SegmentTree tree(cnt);
    int ans = 0;
    for (int i = 0; i < evs.size(); i++) {
        auto curr = evs[i];
        int prib = 0;
        for (int j = 0; j < cnt - 1; j++) {
            prib += tree.sum(j, j + 1) != 0;
        }
        ans += prib * (curr.x - prev);
        if (curr.op) {
            tree.update(coords[curr.y], coords[curr.y + curr.h], 1);
        } else {
            tree.update(coords[curr.y], coords[curr.y + curr.h], -1);
        }
        prev = curr.x;
    }
    cout << ans;
    return 0;
}
/*
1 5
E 2
N 2
W 4
S 4
E 4
*/